@@ -15,6 +15,7 @@
 import time
 
 import six.moves.urllib.parse as urlparse
+from six import text_type
 
 from monasca_tempest_tests.tests.api import base
 from monasca_tempest_tests.tests.api import constants
@@ -203,7 +204,8 @@ class TestNotificationMethods(base.BaseMonascaTest):
                           self.monasca_client.create_notifications,
                           notification)
 
-    # The below tests are making sure that we accept passing in case insensitive types and that we still validate the
+    # The below tests are making sure that we accept passing in case insensitive types
+    # and that we still validate the
     # address if the types are case insensitive
     @decorators.attr(type="gate")
     def test_create_notification_method_webhook_with_lower_case_type(self):
@@ -271,9 +273,10 @@ class TestNotificationMethods(base.BaseMonascaTest):
     @decorators.attr(type=['negative'])
     def test_create_notification_method_with_invalid_type(self):
         notification = helpers.create_notification(type='random')
-        self.assertRaises((exceptions.BadRequest, exceptions.NotFound, exceptions.UnprocessableEntity),
-                          self.monasca_client.create_notifications,
-                          notification)
+        self.assertRaises(
+            (exceptions.BadRequest, exceptions.NotFound, exceptions.UnprocessableEntity),
+            self.monasca_client.create_notifications,
+            notification)
 
     @decorators.attr(type="gate")
     @decorators.attr(type=['negative'])
@@ -334,11 +337,11 @@ class TestNotificationMethods(base.BaseMonascaTest):
         element = elements[0]
         self.assertTrue(set(['id', 'links', 'name', 'type', 'address', 'period']) ==
                         set(element))
-        self.assertTrue(type(element['id']) is unicode)
+        self.assertTrue(type(element['id']) is text_type)
         self.assertTrue(type(element['links']) is list)
-        self.assertTrue(type(element['name']) is unicode)
-        self.assertTrue(type(element['type']) is unicode)
-        self.assertTrue(type(element['address']) is unicode)
+        self.assertTrue(type(element['name']) is text_type)
+        self.assertTrue(type(element['type']) is text_type)
+        self.assertTrue(type(element['address']) is text_type)
 
         resp, response_body = self.monasca_client.\
             delete_notification_method(id)
@@ -662,10 +665,11 @@ class TestNotificationMethods(base.BaseMonascaTest):
             notification)
         id = response_body['id']
         self.assertEqual(201, resp.status)
-        self.assertRaises((exceptions.BadRequest, exceptions.NotFound, exceptions.UnprocessableEntity),
-                          self.monasca_client.update_notification_method, id,
-                          name=response_body['name'], type='random',
-                          address=response_body['address'], period=0)
+        self.assertRaises(
+            (exceptions.BadRequest, exceptions.NotFound, exceptions.UnprocessableEntity),
+            self.monasca_client.update_notification_method,
+            id, name=response_body['name'], type='random',
+            address=response_body['address'], period=0)
         resp, response_body = \
             self.monasca_client.delete_notification_method(id)
         self.assertEqual(204, resp.status)
@@ -967,8 +971,9 @@ class TestNotificationMethods(base.BaseMonascaTest):
             notification)
         id = response_body['id']
         self.assertEqual(201, resp.status)
-        self.assertRaises((exceptions.BadRequest, exceptions.NotFound, exceptions.UnprocessableEntity),
-                          self.monasca_client.patch_notification_method, id, type='random')
+        self.assertRaises(
+            (exceptions.BadRequest, exceptions.NotFound, exceptions.UnprocessableEntity),
+            self.monasca_client.patch_notification_method, id, type='random')
         resp, response_body = \
             self.monasca_client.delete_notification_method(id)
         self.assertEqual(204, resp.status)
@@ -984,8 +989,9 @@ class TestNotificationMethods(base.BaseMonascaTest):
         self.assertEqual(201, resp.status)
         new_address_long = "x" * (
             constants.MAX_NOTIFICATION_METHOD_ADDRESS_LENGTH + 1)
-        self.assertRaises((exceptions.BadRequest, exceptions.UnprocessableEntity),
-                          self.monasca_client.patch_notification_method, id, address=new_address_long)
+        self.assertRaises(
+            (exceptions.BadRequest, exceptions.UnprocessableEntity),
+            self.monasca_client.patch_notification_method, id, address=new_address_long)
         resp, response_body = \
             self.monasca_client.delete_notification_method(id)
         self.assertEqual(204, resp.status)
