@@ -16,6 +16,8 @@
 import time
 
 import six.moves.urllib.parse as urlparse
+from six.moves.urllib.parse import urlencode
+from six import text_type
 
 from monasca_tempest_tests.tests.api import base
 from monasca_tempest_tests.tests.api import constants
@@ -23,7 +25,6 @@ from monasca_tempest_tests.tests.api import helpers
 from tempest.lib.common.utils import data_utils
 from tempest.lib import decorators
 from tempest.lib import exceptions
-from urllib import urlencode
 
 NUM_MEASUREMENTS = 100
 MIN_REQUIRED_MEASUREMENTS = 2
@@ -74,7 +75,8 @@ class TestStatistics(base.BaseMonascaTest):
             time.sleep(constants.RETRY_WAIT_SECS)
 
         if num_measurements < MIN_REQUIRED_MEASUREMENTS:
-            assert False, "Required {} measurements, found {}".format(MIN_REQUIRED_MEASUREMENTS, num_measurements)
+            assert False, "Required {} measurements, found {}".format(MIN_REQUIRED_MEASUREMENTS,
+                                                                      num_measurements)
 
         cls._end_timestamp = cls._start_timestamp + 3000
         cls._end_time_iso = helpers.timestamp_to_iso(cls._end_timestamp)
@@ -84,13 +86,17 @@ class TestStatistics(base.BaseMonascaTest):
         cls._group_by_end_time_iso = helpers.timestamp_to_iso(cls._start_timestamp + 4000)
 
         group_by_metrics = [
-            helpers.create_metric(name=name2, dimensions={'key1': 'value1', 'key2': 'value5', 'key3': 'value7'},
+            helpers.create_metric(name=name2,
+                                  dimensions={'key1': 'value1', 'key2': 'value5', 'key3': 'value7'},
                                   timestamp=cls._start_timestamp + 1, value=2),
-            helpers.create_metric(name=name2, dimensions={'key1': 'value2', 'key2': 'value5', 'key3': 'value7'},
+            helpers.create_metric(name=name2,
+                                  dimensions={'key1': 'value2', 'key2': 'value5', 'key3': 'value7'},
                                   timestamp=cls._start_timestamp + 1001, value=3),
-            helpers.create_metric(name=name2, dimensions={'key1': 'value3', 'key2': 'value6', 'key3': 'value7'},
+            helpers.create_metric(name=name2,
+                                  dimensions={'key1': 'value3', 'key2': 'value6', 'key3': 'value7'},
                                   timestamp=cls._start_timestamp + 2001, value=5),
-            helpers.create_metric(name=name2, dimensions={'key1': 'value4', 'key2': 'value6', 'key3': 'value8'},
+            helpers.create_metric(name=name2,
+                                  dimensions={'key1': 'value4', 'key2': 'value6', 'key3': 'value8'},
                                   timestamp=cls._start_timestamp + 3001, value=7),
         ]
 
@@ -326,7 +332,7 @@ class TestStatistics(base.BaseMonascaTest):
         self.assertEqual(len(elements), 2)
         for statistics in elements:
             self.assertEqual(1, len(statistics['dimensions'].keys()))
-            self.assertEqual([u'key2'], statistics['dimensions'].keys())
+            self.assertEqual([u'key2'], list(statistics['dimensions'].keys()))
 
     @decorators.attr(type="gate")
     def test_list_statistics_with_group_by_multiple(self):
@@ -474,9 +480,9 @@ class TestStatistics(base.BaseMonascaTest):
     def _verify_element(self, element):
         self.assertTrue(set(['id', 'name', 'dimensions', 'columns',
                              'statistics']) == set(element))
-        self.assertTrue(type(element['id']) is unicode)
+        self.assertTrue(type(element['id']) is text_type)
         self.assertTrue(element['id'] is not None)
-        self.assertTrue(type(element['name']) is unicode)
+        self.assertTrue(type(element['name']) is text_type)
         self.assertTrue(type(element['dimensions']) is dict)
         self.assertEqual(len(element['dimensions']), 0)
         self.assertTrue(type(element['columns']) is list)
